@@ -12,10 +12,10 @@ class FileListViewThread(QThread):
     finishFetch = pyqtSignal(QAbstractTableModel)
     def run(self):
         target = self.parent()
-        listmodel = FileListModel(project = target.project, component = target.component, parent=None)
-        listmodel.moveToThread(target.thread())
-        listmodel.setParent(self)
-        self.finishFetch.emit(listmodel)
+        tablemodel = FileListModel(project = target.project, component = target.component, parent=None)
+        tablemodel.moveToThread(target.thread())
+        tablemodel.setParent(self)
+        self.finishFetch.emit(tablemodel)
 
 class FilesView(CustomWindow):
     def __init__(self, parent=None, project=None, component=None):
@@ -31,19 +31,20 @@ class FilesView(CustomWindow):
         self.fetchThread.finishFetch.connect(self.finishFetch)
         self.fetchThread.start()
 
-    def finishFetch(self, listmodel):
-        self.listmodel = listmodel
-        self.tableview.setModel(listmodel)
-        for i in [0,1,2]:
-            self.tableview.resizeColumnToContents(i)
-        self.tableview.resizeRowsToContents()
+    def finishFetch(self, tablemodel):
+        self.tablemodel = tablemodel
+        self.tableview.setModel(tablemodel)
         self.tableview.clicked.connect(self.openFile)
         self.setWindowTitle(u"Files of %s/%s" % (self.project.title, self.component.title))
         self.toggleBusy(False)
+        for i in [0,1,2]:
+            self.tableview.resizeColumnToContents(i)
+        self.tableview.resizeRowsToContents()
         self.tableview.setEnabled(True)
+        self.tableview.setFocus()
 
     def openFile(self, index):
-        remotefile = self.listmodel.data(index)
+        remotefile = self.tablemodel.data(index)
         config.bookmarksChanged.emit()
         obj = FileView(parent=self, fp=remotefile)
         obj.show()
