@@ -167,7 +167,12 @@ class FileView(CustomWindow):
     def setProgress(self, text, value):
         self.pd.setValue(value)
         self.pd.setLabelText(text)
-        sleep(0.05)
+
+    def resizeCells(self):
+        for i in [1,2]:
+            self.tableview.resizeColumnToContents(i)
+        self.tableview.resizeRowsToContents()
+
 
     def setSourceModel(self, source_model):
         self.source_model = source_model
@@ -177,9 +182,7 @@ class FileView(CustomWindow):
             self.model = StringsetProxyModel(source_model)
 
         self.tableview.setModel(self.model)
-        for i in [1,2]:
-            self.tableview.resizeColumnToContents(i)
-        self.tableview.resizeRowsToContents()
+        self.resizeCells()
 
         # Connect signals to slots
         if isinstance(self.model, QSortFilterProxyModel):
@@ -189,7 +192,6 @@ class FileView(CustomWindow):
                 self.model.setFilterFuzzy)
             self.actionFilterUntranslated.toggled.connect(
                 self.model.setFilterUntranslated)
-        self.toggleBusy(False)
         self.tableview.setEnabled(True)
         self.tableview.setFocus()
         
@@ -235,7 +237,7 @@ class FileView(CustomWindow):
             e.ignore()          
 
     def __init__(self, fp=None, parent=None):
-        CustomWindow.__init__(self, parent, busy=True, 
+        CustomWindow.__init__(self, parent, busy=False, 
             skip_central_widget=True)
         self.setWindowTitle(self.tr("Transifex-mobile"))
         self.modified = False # Wether file is modified 
