@@ -75,8 +75,8 @@ class ServerModel(QObject):
     RE_VERSION = """<p\s+class="version">v(?P<major>\d+).(?P<minor>\d+).(?P<revision>\d+)</p>"""
 
     # Regex for /projects/p/PROJECT_SLUG/c/COMPONENT_SLUG
-    #RE_RAW_FILE = r"""<td class="left name" id="(?P<language_code>[-\w]+?)">.*?href=\"/projects/p/(?P<project_slug>[-\w]+?)/c/(?P<component_slug>[-\w]+?)/raw/(?P<filename>.*?)\"></a>"""
-    RE_RAW_FILE = r"""<td class="left name" id="(?P<language_code>[-\w]+?)">.*?<form action=\"/projects/p/(?P<project_slug>[-\w]+?)/c/(?P<component_slug>[-\w]+?)/(?P<locked>.+?)/(?P<filename>.*?)\" method="POST" class="microform">"""
+    #RE_RAW_FILE = r"""<td class="left name" id="(?P<language_code>[-\w]+?)">.*?<form action=\"/projects/p/(?P<project_slug>[-\w]+?)/c/(?P<component_slug>[-\w]+?)/(?P<locked>.+?)/(?P<filename>.*?)\" method="POST" class="microform">"""
+    RE_RAW_FILE = r"""<td class="left name" id="(?P<language_code>[-\w]+?)">.*?<span class='trans_detail'>\((?P<translated>\d+?)/(?P<fuzzy>\d+?)/(?P<untranslated>\d+?)\)</span>.*?<form action=\"/projects/p/(?P<project_slug>[-\w]+?)/c/(?P<component_slug>[-\w]+?)/(?P<locked>.+?)/(?P<filename>.*?)\" method="POST" class="microform">"""
 
     # Regex for /languages
     RE_LANGUAGE = r"""<li class="i16 language"><a href="/languages/l/(?P<language_code>[-\w]+?)/">(?P<language_name>.+?) \([-\w]+?\)</a></li>"""
@@ -291,13 +291,19 @@ class ServerModel(QObject):
             entry.title,
             client=self) for entry in doc.entries]
 
-    def pullFiles(self, project_slug, component_slug):
+    def pullFiles(self, project_slug, component_slug):            
         resp, content, _ = self.request("/projects/p/%s/c/%s/" %
             (project_slug, component_slug))
         m = re.findall(self.RE_RAW_FILE, content, re.MULTILINE|re.DOTALL)
         if m:
-            return [RemoteFileModel(project_slug, component_slug, file_path,
-                client=self, lang_code=language_code, locked=(locked=="unlock")) for language_code,
+            return [RemoteFileModel(
+                project_slug, component_slug, file_path,
+                translated=int(translated),
+                fuzzy=int(fuzzy),
+                untranslated=int(untranslated),
+                client=self, lang_code=language_code, 
+                locked=(locked=="unlock")) for 
+                language_code, translated, fuzzy, untranslated,
                 project_slug, component_slug, locked, file_path in m]
         else:
             return []
